@@ -40,7 +40,7 @@
 
 #include "protect.h"
 
-#if COMPILER(MSVC)
+#if defined(WTF_COMPILER_MSVC)
 #include <windows.h>
 #include <timeapi.h>
 #if HAVE_CRTDBG_H
@@ -48,7 +48,7 @@
 #endif
 #endif
 
-#if PLATFORM(WIN_OS) && ! COMPILER(MSVC)
+#if PLATFORM(WIN_OS) && ! defined(WTF_COMPILER_MSVC)
 #ifndef timersub
 # define timersub(a, b, result)                                               \
   do {                                                                        \
@@ -120,7 +120,7 @@ long StopWatch::getElapsedMS()
 class GlobalImp : public JSGlobalObject
 {
 public:
-    virtual UString className() const
+    UString className() const override
     {
         return "global";
     }
@@ -130,11 +130,11 @@ class TestFunctionImp : public JSObject
 {
 public:
     TestFunctionImp(int i, int length);
-    virtual bool implementsCall() const
+    bool implementsCall() const override
     {
         return true;
     }
-    virtual JSValue *callAsFunction(ExecState *exec, JSObject *thisObj, const List &args);
+    JSValue *callAsFunction(ExecState *exec, JSObject *thisObj, const List &args) override;
 
     enum { Print, Debug, Quit, GC, Version, Run };
 
@@ -151,10 +151,10 @@ JSValue *TestFunctionImp::callAsFunction(ExecState *exec, JSObject *, const List
 {
     switch (id) {
     case Print:
-        printf("--> %s\n", args[0]->toString(exec).UTF8String().c_str());
+        printf("--> %s\n", JSValue::toString(args[0], exec).UTF8String().c_str());
         return jsUndefined();
     case Debug:
-        fprintf(stderr, "--> %s\n", args[0]->toString(exec).UTF8String().c_str());
+        fprintf(stderr, "--> %s\n", JSValue::toString(args[0], exec).UTF8String().c_str());
         return jsUndefined();
     case GC: {
         JSLock lock;
@@ -167,7 +167,7 @@ JSValue *TestFunctionImp::callAsFunction(ExecState *exec, JSObject *, const List
         return jsUndefined();
     case Run: {
         StopWatch stopWatch;
-        char *fileName = strdup(args[0]->toString(exec).UTF8String().c_str());
+        char *fileName = strdup(JSValue::toString(args[0], exec).UTF8String().c_str());
         char *script = createStringWithContentsOfFile(fileName);
         if (!script) {
             return throwError(exec, GeneralError, "Could not open file.");
@@ -253,6 +253,9 @@ bool doIt(int argc, char **argv)
     global->put(interp->globalExec(), "version", new TestFunctionImp(TestFunctionImp::Version, 1));
     global->put(interp->globalExec(), "run", new TestFunctionImp(TestFunctionImp::Run, 1));
 
+    // abort evaluation of single script file after 5 seconds
+    interp->setTimeoutTime(5000);
+
     Interpreter::setShouldPrintExceptions(true);
 
     for (int i = 1; i < argc; i++) {
@@ -288,7 +291,9 @@ bool doIt(int argc, char **argv)
         } else
 #endif
         {
+            interp->startTimeoutCheck();
             Completion completion = interp->evaluate(fileName, 0, script);
+            interp->stopTimeoutCheck();
             success = success && completion.complType() != Throw;
         }
         free(script);
